@@ -30,7 +30,7 @@ class knumber_float : public knumber_base {
 	friend class knumber_error;
 	friend class knumber_integer;
 	friend class knumber_fraction;
-	
+
 private:
 #ifdef KNUMBER_USE_MPFR
 	static const mpfr_rnd_t  rounding_mode;
@@ -42,11 +42,11 @@ public:
 	explicit knumber_float(double value);
 #ifdef HAVE_LONG_DOUBLE
 	explicit knumber_float(long double value);
-#endif	
-	
+#endif
+
 	explicit knumber_float(mpf_t mpf);
 	virtual ~knumber_float();
-	
+
 private:
 	// conversion constructors
 	explicit knumber_float(const knumber_integer *value);
@@ -58,7 +58,7 @@ public:
 	virtual QString toString(int precision) const;
 	virtual quint64 toUint64() const;
 	virtual qint64 toInt64() const;
-	
+
 public:
 	virtual bool is_integer() const;
 	virtual bool is_zero() const;
@@ -70,7 +70,7 @@ public:
 	virtual knumber_base *mul(knumber_base *rhs);
 	virtual knumber_base *div(knumber_base *rhs);
 	virtual knumber_base *mod(knumber_base *rhs);
-	
+
 public:
 	virtual knumber_base *pow(knumber_base *rhs);
 	virtual knumber_base *neg();
@@ -80,16 +80,19 @@ public:
 	virtual knumber_base *cbrt();
 	virtual knumber_base *factorial();
 	virtual knumber_base *reciprocal();
-	
+	virtual knumber_base *tgamma();
+
 public:
 	virtual knumber_base *log2();
 	virtual knumber_base *log10();
 	virtual knumber_base *ln();
+	virtual knumber_base *floor();
+	virtual knumber_base *ceil();
 	virtual knumber_base *exp2();
 	virtual knumber_base *exp10();
 	virtual knumber_base *exp();
 	virtual knumber_base *bin(knumber_base *rhs);
-	
+
 public:
 	virtual knumber_base *sin();
 	virtual knumber_base *cos();
@@ -103,10 +106,10 @@ public:
 	virtual knumber_base *asinh();
 	virtual knumber_base *acosh();
 	virtual knumber_base *atanh();
-	
+
 public:
 	virtual int compare(knumber_base *rhs);
-	
+
 public:
 	virtual knumber_base *bitwise_and(knumber_base *rhs);
 	virtual knumber_base *bitwise_xor(knumber_base *rhs);
@@ -115,14 +118,14 @@ public:
 
 public:
 	virtual knumber_base *clone();
-	
+
 private:
 	template <double F(double)>
 	knumber_base *execute_libc_func(double x);
 
 	template <double F(double, double)>
 	knumber_base *execute_libc_func(double x, double y);
-	
+
 private:
 	mpf_t mpf_;
 };
